@@ -97,52 +97,6 @@ struct _BraseroProcessPrivate {
 
 #define BRASERO_PROCESS_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_PROCESS, BraseroProcessPrivate))
 
-static GObjectClass *parent_class = NULL;
-
-/* This is a helper function for plugins at load time */
-
-gboolean
-brasero_process_check_path (const gchar *name,
-			    gchar **error)
-{
-	gchar *prog_path;
-
-	/* First see if this plugin can be used, i.e. if cdrecord is in
-	 * the path */
-	prog_path = g_find_program_in_path (name);
-	if (!prog_path) {
-		*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
-		return BRASERO_BURN_ERR;
-	}
-
-	if (!g_file_test (prog_path, G_FILE_TEST_IS_EXECUTABLE)) {
-		g_free (prog_path);
-		*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
-		return BRASERO_BURN_ERR;
-	}
-
-	/* make sure that's not a symlink pointing to something with another
-	 * name like wodim.
-	 * NOTE: we used to test the target and see if it had the same name as
-	 * the symlink with GIO. The problem is, when the symlink pointed to
-	 * another symlink, then GIO didn't follow that other symlink. And in
-	 * the end it didn't work. So forbid all symlink. */
-	if (g_file_test (prog_path, G_FILE_TEST_IS_SYMLINK)) {
-		*error = g_strdup_printf (_("\"%s\" is a symbolic link pointing to another program. Use the target program instead"), name);
-		g_free (prog_path);
-		return BRASERO_BURN_ERR;
-	}
-	/* Make sure it's a regular file */
-	else if (!g_file_test (prog_path, G_FILE_TEST_IS_REGULAR)) {
-		*error = g_strdup_printf (_("\"%s\" could not be found in the path"), name);
-		g_free (prog_path);
-		return BRASERO_BURN_ERR;
-	}
-
-	g_free (prog_path);
-	return BRASERO_BURN_OK;
-}
-
 void
 brasero_process_deferred_error (BraseroProcess *self,
 				GError *error)
@@ -323,14 +277,14 @@ brasero_process_finished (BraseroProcess *self)
 	}
 
 	/* Tell the world we're done */
-	klass->post (BRASERO_JOB (self));
-	return BRASERO_BURN_OK;
+	return klass->post (BRASERO_JOB (self));
 }
 
 static gboolean
 brasero_process_watch_child (gpointer data)
 {
 	int status;
+	BraseroBurnResult result;
 	BraseroProcessPrivate *priv = BRASERO_PROCESS_PRIVATE (data);
 
 	if (waitpid (priv->pid, &status, WNOHANG) <= 0)
@@ -342,9 +296,33 @@ brasero_process_watch_child (gpointer data)
 	 * error message or simply decide all went well, in one word override */
 	priv->return_status = WEXITSTATUS (status);
 	priv->watch = 0;
+	priv->pid = 0;
 
 	BRASERO_JOB_LOG (data, "process finished with status %i", WEXITSTATUS (status));
-	brasero_process_finished (BRASERO_PROCESS (data));
+
+	result = brasero_process_finished (data);
+	if (result == BRASERO_BURN_RETRY) {
+		GError *error = NULL;
+		BraseroJobClass *job_class;
+
+		priv->process_finished = FALSE;
+
+		job_class = BRASERO_JOB_GET_CLASS (data);
+		if (job_class->stop) {
+			result = job_class->stop (data, &error);
+			if (result != BRASERO_BURN_OK) {
+				brasero_job_error (data, error);
+				return FALSE;
+			}
+		}
+
+		if (job_class->start) {
+			/* we were asked by the plugin to restart it */
+			result = job_class->start (data, &error);
+			if (result != BRASERO_BURN_OK)
+				brasero_job_error (data, error);
+		}
+	}
 
 	return FALSE;
 }
@@ -903,7 +881,7 @@ brasero_process_finalize (GObject *object)
 		priv->working_directory = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (brasero_process_parent_class)->finalize (object);
 }
 
 static void
@@ -914,7 +892,6 @@ brasero_process_class_init (BraseroProcessClass *klass)
 
 	g_type_class_add_private (klass, sizeof (BraseroProcessPrivate));
 
-	parent_class = g_type_class_peek_parent(klass);
 	object_class->finalize = brasero_process_finalize;
 
 	job_class->start = brasero_process_start;
