@@ -47,17 +47,22 @@
 
 #include <gmodule.h>
 
-#include <gconf/gconf-client.h>
-
 #include "brasero-plugin-registration.h"
 #include "burn-job.h"
-#include "burn-checksum-image.h"
 #include "burn-volume.h"
 #include "brasero-drive.h"
 #include "brasero-track-disc.h"
 #include "brasero-track-image.h"
 #include "brasero-tags.h"
 
+
+#define BRASERO_TYPE_CHECKSUM_IMAGE		(brasero_checksum_image_get_type ())
+#define BRASERO_CHECKSUM_IMAGE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImage))
+#define BRASERO_CHECKSUM_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImageClass))
+#define BRASERO_IS_CHECKSUM_IMAGE(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_CHECKSUM_IMAGE))
+#define BRASERO_IS_CHECKSUM_IMAGE_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_CHECKSUM_IMAGE))
+#define BRASERO_CHECKSUM_GET_CLASS(o)		(G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImageClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroChecksumImage, brasero_checksum_image, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroChecksumImagePrivate {
@@ -80,7 +85,8 @@ typedef struct _BraseroChecksumImagePrivate BraseroChecksumImagePrivate;
 
 #define BRASERO_CHECKSUM_IMAGE_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImagePrivate))
 
-#define GCONF_KEY_CHECKSUM_TYPE		"/apps/brasero/config/checksum_image"
+#define BRASERO_SCHEMA_CONFIG		"org.gnome.brasero.config"
+#define BRASERO_PROPS_CHECKSUM_IMAGE	"checksum-image"
 
 static BraseroJobClass *parent_class = NULL;
 
@@ -412,12 +418,12 @@ brasero_checksum_image_create_checksum (BraseroChecksumImage *self,
 static BraseroChecksumType
 brasero_checksum_get_checksum_type (void)
 {
-	GConfClient *client;
+	GSettings *settings;
 	GChecksumType checksum_type;
 
-	client = gconf_client_get_default ();
-	checksum_type = gconf_client_get_int (client, GCONF_KEY_CHECKSUM_TYPE, NULL);
-	g_object_unref (client);
+	settings = g_settings_new (BRASERO_SCHEMA_CONFIG);
+	checksum_type = g_settings_get_int (settings, BRASERO_PROPS_CHECKSUM_IMAGE);
+	g_object_unref (settings);
 
 	return checksum_type;
 }
@@ -698,12 +704,14 @@ brasero_checksum_image_clock_tick (BraseroJob *job)
 	BraseroChecksumImagePrivate *priv;
 
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (job);
+
 	if (!priv->checksum)
 		return BRASERO_BURN_OK;
 
 	if (!priv->total)
 		return BRASERO_BURN_OK;
 
+	brasero_job_start_progress (job, FALSE);
 	brasero_job_set_progress (job,
 				  (gdouble) priv->bytes /
 				  (gdouble) priv->total);
@@ -808,18 +816,19 @@ brasero_checksum_image_class_init (BraseroChecksumImageClass *klass)
 	job_class->clock_tick = brasero_checksum_image_clock_tick;
 }
 
-static BraseroBurnResult
-brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
+static void
+brasero_checksum_image_export_caps (BraseroPlugin *plugin)
 {
 	GSList *input;
 	BraseroPluginConfOption *checksum_type;
 
 	brasero_plugin_define (plugin,
+	                       "image-checksum",
 			       /* Translators: this is the name of the plugin
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("Image Checksum"),
-			       _("Allows to check data integrity on disc after it is burnt"),
+			       _("Checks disc integrity after it is burnt"),
 			       "Philippe Rouquier",
 			       0);
 
@@ -842,7 +851,7 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (input);
 
 	/* add some configure options */
-	checksum_type = brasero_plugin_conf_option_new (GCONF_KEY_CHECKSUM_TYPE,
+	checksum_type = brasero_plugin_conf_option_new (BRASERO_PROPS_CHECKSUM_IMAGE,
 							_("Hashing algorithm to be used:"),
 							BRASERO_PLUGIN_OPTION_CHOICE);
 	brasero_plugin_conf_option_choice_add (checksum_type,
@@ -855,6 +864,4 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_add_conf_option (plugin, checksum_type);
 
 	brasero_plugin_set_compulsory (plugin, FALSE);
-
-	return BRASERO_BURN_OK;
 }
