@@ -1073,7 +1073,6 @@ brasero_project_init (BraseroProject *obj)
 
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 
-	/* burn button set insensitive since there are no files in the selection */
 	obj->priv->burn = brasero_utils_make_button (_("_Burn…"),
 						     NULL,
 						     "media-optical-burn",
@@ -1164,7 +1163,6 @@ brasero_project_init (BraseroProject *obj)
 			    0);
 
 	g_object_unref (size_group);
-	
 }
 
 static void
@@ -1894,7 +1892,7 @@ brasero_project_confirm_switch (BraseroProject *project,
 			return TRUE;
 
 		dialog = brasero_app_dialog (brasero_app_get_default (),
-					     _("Do you really want to create a new project and discard the changes to current one?"),
+					     _("Do you really want to create a new project and discard the current one?"),
 					     GTK_BUTTONS_CANCEL,
 					     GTK_MESSAGE_WARNING);
 
@@ -2023,6 +2021,9 @@ void
 brasero_project_set_source (BraseroProject *project,
 			    BraseroURIContainer *source)
 {
+	if (project->priv->chooser)
+		gtk_dialog_response (GTK_DIALOG (project->priv->chooser), GTK_RESPONSE_CANCEL);
+
 	if (project->priv->activated_id) {
 		g_signal_handler_disconnect (project->priv->current_source,
 					     project->priv->activated_id);
@@ -2657,7 +2658,7 @@ brasero_project_save_project_real (BraseroProject *project,
 				   const gchar *uri,
 				   BraseroProjectSave save_type)
 {
-	BraseroDiscResult result;
+	BraseroBurnResult result;
 	BraseroProjectType type;
 
 	g_return_val_if_fail (uri != NULL || project->priv->project != NULL, FALSE);
@@ -2666,19 +2667,6 @@ brasero_project_save_project_real (BraseroProject *project,
 	if (result != BRASERO_BURN_OK)
 		return FALSE;
 
-	if (result == BRASERO_DISC_ERROR_EMPTY_SELECTION) {
-		if (BRASERO_IS_AUDIO_DISC (project->priv->current))
-			brasero_project_no_song_dialog (project);
-		else if (BRASERO_IS_DATA_DISC (project->priv->current))
-			brasero_project_no_file_dialog (project);
-
-		return FALSE;
-	}
-	else if (result != BRASERO_DISC_OK) {
-		brasero_project_not_saved_dialog (project);
-		return FALSE;
-	}
-
 	brasero_project_setup_session (project, BRASERO_BURN_SESSION (project->priv->session));
         type = brasero_project_get_session_type (project);
 
