@@ -361,7 +361,8 @@ brasero_video_disc_directory_dialog (BraseroVideoDisc *self)
 				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Directories cannot be added to video discs."));
+	                                          "%s.",
+						  _("Directories cannot be added to video or audio discs"));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
